<?php
namespace App\Controllers;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;

class ImageController {
    protected $db;
    
    public function __construct($container) {
        $this->db = $container->get('db');
    }
    
    // Récupérer toutes les images
    public function getImages(Request $request, Response $response, $args) {
        $sql = "SELECT * FROM Image";
        try {
            $stmt = $this->db->query($sql);
            $images = $stmt->fetchAll(\PDO::FETCH_OBJ);
            $payload = json_encode($images);
        } catch (\PDOException $e) {
            $payload = json_encode(['error' => $e->getMessage()]);
        }
        $response->getBody()->write($payload);
        return $response->withHeader('Content-Type', 'application/json');
    }
    
    // Récupérer une image par son ID
    public function getImage(Request $request, Response $response, $args) {
        $id = $args['id'];
        $sql = "SELECT * FROM Image WHERE id_img = :id";
        try {
            $stmt = $this->db->prepare($sql);
            $stmt->bindParam("id", $id);
            $stmt->execute();
            $image = $stmt->fetch(\PDO::FETCH_OBJ);
            if(!$image){
                $payload = json_encode(['message' => 'Image not found']);
                $response->getBody()->write($payload);
                return $response->withHeader('Content-Type', 'application/json')->withStatus(404);
            }
            $payload = json_encode($image);
        } catch (\PDOException $e) {
            $payload = json_encode(['error' => $e->getMessage()]);
        }
        $response->getBody()->write($payload);
        return $response->withHeader('Content-Type', 'application/json');
    }
    
    // Créer une nouvelle image
    public function createImage(Request $request, Response $response, $args) {
        $data = $request->getParsedBody();
        $sql = "INSERT INTO Image (imgPath) VALUES (:imgPath)";
        try {
            $stmt = $this->db->prepare($sql);
            $stmt->bindParam("imgPath", $data['imgPath']);
            $stmt->execute();
            $data['id_img'] = $this->db->lastInsertId();
            $payload = json_encode($data);
        } catch (\PDOException $e) {
            $payload = json_encode(['error' => $e->getMessage()]);
        }
        $response->getBody()->write($payload);
        return $response->withHeader('Content-Type', 'application/json');
    }
}
