<?php
namespace App\Controllers;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;

class UserController {
    protected $db;
    
    public function __construct($container) {
        $this->db = $container->get('db');
    }
    
    // Récupérer tous les utilisateurs
    public function getUsers(Request $request, Response $response, $args) {
        $sql = "SELECT * FROM Users";
        try {
            $stmt = $this->db->query($sql);
            $users = $stmt->fetchAll(\PDO::FETCH_OBJ);
            $payload = json_encode($users);
        } catch (\PDOException $e) {
            $payload = json_encode(['error' => $e->getMessage()]);
        }
        $response->getBody()->write($payload);
        return $response->withHeader('Content-Type', 'application/json');
    }
    
    // Récupérer un utilisateur par son ID
    public function getUser(Request $request, Response $response, $args) {
        $id = $args['id'];
        $sql = "SELECT * FROM Users WHERE id_user = :id";
        try {
            $stmt = $this->db->prepare($sql);
            $stmt->bindParam("id", $id);
            $stmt->execute();
            $user = $stmt->fetch(\PDO::FETCH_OBJ);
            if(!$user){
                $payload = json_encode(['message' => 'User not found']);
                $response->getBody()->write($payload);
                return $response->withHeader('Content-Type', 'application/json')->withStatus(404);
            }
            $payload = json_encode($user);
        } catch (\PDOException $e) {
            $payload = json_encode(['error' => $e->getMessage()]);
        }
        $response->getBody()->write($payload);
        return $response->withHeader('Content-Type', 'application/json');
    }
    
    // Créer un nouvel utilisateur
    public function createUser(Request $request, Response $response, $args) {
        $data = $request->getParsedBody();
        $sql = "INSERT INTO Users (username, email, password, img, creation) VALUES (:username, :email, :password, :img, :creation)";
        try {
            $stmt = $this->db->prepare($sql);
            $stmt->bindParam("username", $data['username']);
            $stmt->bindParam("email", $data['email']);
            $stmt->bindParam("password", $data['password']);
            $stmt->bindParam("img", $data['img']);
            $stmt->bindParam("creation", $data['creation']);
            $stmt->execute();
            $data['id_user'] = $this->db->lastInsertId();
            $payload = json_encode($data);
        } catch (\PDOException $e) {
            $payload = json_encode(['error' => $e->getMessage()]);
        }
        $response->getBody()->write($payload);
        return $response->withHeader('Content-Type', 'application/json');
    }
    
    // Mettre à jour un utilisateur
    public function updateUser(Request $request, Response $response, $args) {
        $id = $args['id'];
        $data = $request->getParsedBody();
        $sql = "UPDATE Users SET username = :username, email = :email, password = :password, img = :img, creation = :creation WHERE id_user = :id";
        try {
            $stmt = $this->db->prepare($sql);
            $stmt->bindParam("username", $data['username']);
            $stmt->bindParam("email", $data['email']);
            $stmt->bindParam("password", $data['password']);
            $stmt->bindParam("img", $data['img']);
            $stmt->bindParam("creation", $data['creation']);
            $stmt->bindParam("id", $id);
            $stmt->execute();
            $payload = json_encode(['message' => 'User updated']);
        } catch (\PDOException $e) {
            $payload = json_encode(['error' => $e->getMessage()]);
        }
        $response->getBody()->write($payload);
        return $response->withHeader('Content-Type', 'application/json');
    }
    
    // Supprimer un utilisateur
    public function deleteUser(Request $request, Response $response, $args) {
        $id = $args['id'];
        $sql = "DELETE FROM Users WHERE id_user = :id";
        try {
            $stmt = $this->db->prepare($sql);
            $stmt->bindParam("id", $id);
            $stmt->execute();
            $payload = json_encode(['message' => 'User deleted']);
        } catch (\PDOException $e) {
            $payload = json_encode(['error' => $e->getMessage()]);
        }
        $response->getBody()->write($payload);
        return $response->withHeader('Content-Type', 'application/json');
    }
}
